==> blesta-5.10.2.zip: blesta/components/modules/virtualmin/language/fr_fr/virtualmin.php <==
<?php
/**
 * Virtualmin
 *
 * @package blesta
 * @subpackage blesta.language.fr_fr
 * @copyright Copyright (c) 2024, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['Virtualmin.name'] = 'VirtualMin';
$lang['Virtualmin.description'] = 'Virtualmin est un panneau de contrôle pour l\'hébergement de domaines et de sites web, qui permet de créer et de gérer de nombreux domaines. Il est disponible en version open source et en version commerciale. Il est basé sur Webmin.';
$lang['Virtualmin.module_row'] = 'Serveur';
$lang['Virtualmin.module_row_plural'] = 'Serveurs';
$lang['Virtualmin.module_group'] = 'Groupe de serveurs';
$lang['Virtualmin.tab_stats'] = 'Statistiques';
$lang['Virtualmin.tab_client_actions'] = 'Actions';
$lang['Virtualmin.add_module_row'] = 'Ajouter un serveur';
$lang['Virtualmin.add_module_group'] = 'Ajouter un groupe de serveurs';
$lang['Virtualmin.manage.module_rows_title'] = 'Serveurs';
$lang['Virtualmin.manage.module_groups_title'] = 'Groupes de serveurs';
$lang['Virtualmin.manage.module_rows_heading.name'] = 'Label du serveur';
$lang['Virtualmin.manage.module_rows_heading.hostname'] = 'Nom d\'hôte';
$lang['Virtualmin.manage.module_rows_heading.port'] = 'Port';
$lang['Virtualmin.manage.module_rows_heading.accounts'] = 'Comptes';
$lang['Virtualmin.manage.module_rows_heading.options'] = 'Options';
$lang['Virtualmin.manage.module_groups_heading.name'] = 'Nom du groupe';
$lang['Virtualmin.manage.module_groups_heading.servers'] = 'Nombre de serveurs';
$lang['Virtualmin.manage.module_groups_heading.options'] = 'Options';
$lang['Virtualmin.manage.module_rows.count'] = '%1$s / %2$s';
$lang['Virtualmin.manage.module_rows.edit'] = 'Editer';
$lang['Virtualmin.manage.module_groups.edit'] = 'Editer';
$lang['Virtualmin.manage.module_rows.delete'] = 'Supprimer';
$lang['Virtualmin.manage.module_groups.delete'] = 'Supprimer';
$lang['Virtualmin.manage.module_rows.confirm_delete'] = 'Êtes-vous sûr de vouloir supprimer ce serveur ?';
$lang['Virtualmin.manage.module_groups.confirm_delete'] = 'Êtes-vous sûr de vouloir supprimer ce groupe de serveurs ?';
$lang['Virtualmin.manage.module_rows_no_results'] = 'Il n\'y a pas de serveurs.';
$lang['Virtualmin.manage.module_groups_no_results'] = 'Il n\'y a pas de groupes de serveurs.';
$lang['Virtualmin.order_options.first'] = 'Premier serveur non complet';
$lang['Virtualmin.add_row.box_title'] = 'Ajouter un serveur VirtualMin';
$lang['Virtualmin.add_row.basic_title'] = 'Paramètres de base';
$lang['Virtualmin.add_row.add_btn'] = 'Ajouter un serveur';
$lang['Virtualmin.edit_row.box_title'] = 'Modifier le serveur VirtualMin';
$lang['Virtualmin.edit_row.basic_title'] = 'Paramètres de base';
$lang['Virtualmin.edit_row.add_btn'] = 'Editer le serveur';
$lang['Virtualmin.row_meta.server_name'] = 'Label du serveur';
$lang['Virtualmin.row_meta.host_name'] = 'Nom d\'hôte';
$lang['Virtualmin.row_meta.user_name'] = 'Nom de l\'utilisateur';
$lang['Virtualmin.row_meta.password'] = 'Mot de passe';
$lang['Virtualmin.row_meta.port'] = 'Port';
$lang['Virtualmin.row_meta.use_ssl'] = 'Utiliser SSL lors de la connexion à l\'API (recommandé)';
$lang['Virtualmin.row_meta.account_limit'] = 'Limite du compte';
$lang['Virtualmin.package_fields.plan'] = 'Plan VirtualMin';
$lang['Virtualmin.package_fields.template'] = 'Modèle VirtualMin';
$lang['Virtualmin.service_field.domain'] = 'Domaine';
$lang['Virtualmin.service_field.username'] = 'Nom d\'utilisateur';
$lang['Virtualmin.service_field.password'] = 'Mot de passe';
$lang['Virtualmin.service_field.confirm_password'] = 'Confirmer le mot de passe';
$lang['Virtualmin.tab_client_actions.change_password'] = 'Modifier le mot de passe';
$lang['Virtualmin.tab_client_actions.field_virtualmin_password'] = 'Mot de passe';
$lang['Virtualmin.tab_client_actions.field_virtualmin_confirm_password'] = 'Confirmer le mot de passe';
$lang['Virtualmin.tab_client_actions.field_password_submit'] = 'Mise à jour du mot de passe';
$lang['Virtualmin.tab_stats.info_title'] = 'Informations';
$lang['Virtualmin.tab_stats.info_heading.field'] = 'Champ d\'application';
$lang['Virtualmin.tab_stats.info_heading.value'] = 'Valeur';
$lang['Virtualmin.tab_stats.info.disk_used'] = 'Disque utilisé';
$lang['Virtualmin.tab_stats.info.databases_size'] = 'Taille de la base de données';
$lang['Virtualmin.tab_stats.info.databases_count'] = 'Compte de la base de données';
$lang['Virtualmin.tab_stats.info.maximum_databases'] = 'Bases de données maximales';
$lang['Virtualmin.tab_stats.info.maximum_mailboxes'] = 'Nombre maximal de boîtes aux lettres';
$lang['Virtualmin.service_info.username'] = 'Nom d\'utilisateur';
$lang['Virtualmin.service_info.password'] = 'Mot de passe';
$lang['Virtualmin.service_info.server'] = 'Serveur';
$lang['Virtualmin.service_info.options'] = 'Options';
$lang['Virtualmin.service_info.option_login'] = 'Se connecter';
$lang['Virtualmin.service_field.tooltip.username'] = 'Vous pouvez laisser le nom d\'utilisateur vide pour qu\'il soit généré automatiquement.';
$lang['Virtualmin.service_field.tooltip.password'] = 'Vous pouvez laisser le mot de passe en blanc pour qu\'il soit généré automatiquement.';
$lang['Virtualmin.!error.server_name_valid'] = 'Vous devez saisir une étiquette de serveur.';
$lang['Virtualmin.!error.host_name_valid'] = 'Le nom d\'hôte semble être invalide.';
$lang['Virtualmin.!error.user_name_valid'] = 'Le nom d\'utilisateur semble être invalide.';
$lang['Virtualmin.!error.port_valid'] = 'Le port semble être invalide.';
$lang['Virtualmin.!error.password_valid'] = 'Le mot de passe semble être invalide.';
$lang['Virtualmin.!error.password_valid_connection'] = 'La connexion au serveur n\'a pas pu être établie. Veuillez vérifier que le nom d\'hôte, le nom d\'utilisateur, le mot de passe et le port sont corrects.';
$lang['Virtualmin.!error.account_limit_valid'] = 'Veuillez saisir une limite de compte valide.';
$lang['Virtualmin.!error.meta[plan].empty'] = 'Un plan VirtualMin est nécessaire.';
$lang['Virtualmin.!error.meta[template].empty'] = 'Un modèle VirtualMin est nécessaire.';
$lang['Virtualmin.!error.api.internal'] = 'Une erreur interne s\'est produite ou le serveur n\'a pas répondu à la demande.';
$lang['Virtualmin.!error.module_row.missing'] = 'Une erreur interne s\'est produite. La ligne du module n\'est pas disponible.';
$lang['Virtualmin.!error.virtualmin_domain.format'] = 'Veuillez saisir un nom de domaine valide, par exemple domain.com.';
$lang['Virtualmin.!error.virtualmin_domain.test'] = 'Le nom de domaine ne peut pas commencer par "test".';
$lang['Virtualmin.!error.virtualmin_username.format'] = 'Le nom d\'utilisateur ne peut contenir que des lettres et des chiffres et ne peut pas commencer par un chiffre.';
$lang['Virtualmin.!error.virtualmin_username.test'] = 'Le nom d\'utilisateur ne peut pas commencer par "test".';
$lang['Virtualmin.!error.virtualmin_username.length'] = 'Le nom d\'utilisateur doit comporter entre 1 et 16 caractères.';
$lang['Virtualmin.!error.virtualmin_password.valid'] = 'Le mot de passe doit comporter au moins 8 caractères.';

==> blesta-5.11.4.zip: blesta/components/modules/virtualmin/language/fr_fr/virtualmin.php <==
<?php
/**
 * Virtualmin
 *
 * @package blesta
 * @subpackage blesta.language.fr_fr
 * @copyright Copyright (c) 2025, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['Virtualmin.name'] = 'VirtualMin';
$lang['Virtualmin.description'] = 'Virtualmin est un panneau de contrôle pour l\'hébergement de domaines et de sites web, qui permet de créer et de gérer de nombreux domaines. Il est disponible en version open source et en version commerciale. Il est basé sur Webmin.';
$lang['Virtualmin.module_row'] = 'Serveur';
$lang['Virtualmin.module_row_plural'] = 'Serveurs';
$lang['Virtualmin.module_group'] = 'Groupe de serveurs';
$lang['Virtualmin.tab_stats'] = 'Statistiques';
$lang['Virtualmin.tab_client_actions'] = 'Actions';
$lang['Virtualmin.add_module_row'] = 'Ajouter un serveur';
$lang['Virtualmin.add_module_group'] = 'Ajouter un groupe de serveurs';
$lang['Virtualmin.manage.module_rows_title'] = 'Serveurs';
$lang['Virtualmin.manage.module_groups_title'] = 'Groupes de serveurs';
$lang['Virtualmin.manage.module_rows_heading.name'] = 'Label du serveur';
$lang['Virtualmin.manage.module_rows_heading.hostname'] = 'Nom d\'hôte';
$lang['Virtualmin.manage.module_rows_heading.port'] = 'Port';
$lang['Virtualmin.manage.module_rows_heading.accounts'] = 'Comptes';
$lang['Virtualmin.manage.module_rows_heading.options'] = 'Options';
$lang['Virtualmin.manage.module_groups_heading.name'] = 'Nom du groupe';
$lang['Virtualmin.manage.module_groups_heading.servers'] = 'Nombre de serveurs';
$lang['Virtualmin.manage.module_groups_heading.options'] = 'Options';
$lang['Virtualmin.manage.module_rows.count'] = '%1$s / %2$s';
$lang['Virtualmin.manage.module_rows.edit'] = 'Editer';
$lang['Virtualmin.manage.module_groups.edit'] = 'Editer';
$lang['Virtualmin.manage.module_rows.delete'] = 'Supprimer';
$lang['Virtualmin.manage.module_groups.delete'] = 'Supprimer';
$lang['Virtualmin.manage.module_rows.confirm_delete'] = 'Êtes-vous sûr de vouloir supprimer ce serveur ?';
$lang['Virtualmin.manage.module_groups.confirm_delete'] = 'Êtes-vous sûr de vouloir supprimer ce groupe de serveurs ?';
$lang['Virtualmin.manage.module_rows_no_results'] = 'Il n\'y a pas de serveurs.';
$lang['Virtualmin.manage.module_groups_no_results'] = 'Il n\'y a pas de groupes de serveurs.';
$lang['Virtualmin.order_options.first'] = 'Premier serveur non complet';
$lang['Virtualmin.add_row.box_title'] = 'Ajouter un serveur VirtualMin';
$lang['Virtualmin.add_row.basic_title'] = 'Paramètres de base';
$lang['Virtualmin.add_row.add_btn'] = 'Ajouter un serveur';
$lang['Virtualmin.edit_row.box_title'] = 'Modifier le serveur VirtualMin';
$lang['Virtualmin.edit_row.basic_title'] = 'Paramètres de base';
$lang['Virtualmin.edit_row.add_btn'] = 'Editer le serveur';
$lang['Virtualmin.row_meta.server_name'] = 'Label du serveur';
$lang['Virtualmin.row_meta.host_name'] = 'Nom d\'hôte';
$lang['Virtualmin.row_meta.user_name'] = 'Nom de l\'utilisateur';
$lang['Virtualmin.row_meta.password'] = 'Mot de passe';
$lang['Virtualmin.row_meta.port'] = 'Port';
$lang['Virtualmin.row_meta.use_ssl'] = 'Utiliser SSL lors de la connexion à l\'API (recommandé)';
$lang['Virtualmin.row_meta.account_limit'] = 'Limite du compte';
$lang['Virtualmin.package_fields.plan'] = 'Plan VirtualMin';
$lang['Virtualmin.package_fields.template'] = 'Modèle VirtualMin';
$lang['Virtualmin.service_field.domain'] = 'Domaine';
$lang['Virtualmin.service_field.username'] = 'Nom d\'utilisateur';
$lang['Virtualmin.service_field.password'] = 'Mot de passe';
$lang['Virtualmin.service_field.confirm_password'] = 'Confirmer le mot de passe';
$lang['Virtualmin.tab_client_actions.change_password'] = 'Modifier le mot de passe';
$lang['Virtualmin.tab_client_actions.field_virtualmin_password'] = 'Mot de passe';
$lang['Virtualmin.tab_client_actions.field_virtualmin_confirm_password'] = 'Confirmer le mot de passe';
$lang['Virtualmin.tab_client_actions.field_password_submit'] = 'Mise à jour du mot de passe';
$lang['Virtualmin.tab_stats.info_title'] = 'Informations';
$lang['Virtualmin.tab_stats.info_heading.field'] = 'Champ d\'application';
$lang['Virtualmin.tab_stats.info_heading.value'] = 'Valeur';
$lang['Virtualmin.tab_stats.info.disk_used'] = 'Disque utilisé';
$lang['Virtualmin.tab_stats.info.databases_size'] = 'Taille de la base de données';
$lang['Virtualmin.tab_stats.info.databases_count'] = 'Compte de la base de données';
$lang['Virtualmin.tab_stats.info.maximum_databases'] = 'Bases de données maximales';
$lang['Virtualmin.tab_stats.info.maximum_mailboxes'] = 'Nombre maximal de boîtes aux lettres';
$lang['Virtualmin.service_info.username'] = 'Nom d\'utilisateur';
$lang['Virtualmin.service_info.password'] = 'Mot de passe';
$lang['Virtualmin.service_info.server'] = 'Serveur';
$lang['Virtualmin.service_info.options'] = 'Options';
$lang['Virtualmin.service_info.option_login'] = 'Se connecter';
$lang['Virtualmin.service_field.tooltip.username'] = 'Vous pouvez laisser le nom d\'utilisateur vide pour qu\'il soit généré automatiquement.';
$lang['Virtualmin.service_field.tooltip.password'] = 'Vous pouvez laisser le mot de passe en blanc pour qu\'il soit généré automatiquement.';
$lang['Virtualmin.!error.server_name_valid'] = 'Vous devez saisir une étiquette de serveur.';
$lang['Virtualmin.!error.host_name_valid'] = 'Le nom d\'hôte semble être invalide.';
$lang['Virtualmin.!error.user_name_valid'] = 'Le nom d\'utilisateur semble être invalide.';
$lang['Virtualmin.!error.port_valid'] = 'Le port semble être invalide.';
$lang['Virtualmin.!error.password_valid'] = 'Le mot de passe semble être invalide.';
$lang['Virtualmin.!error.password_valid_connection'] = 'La connexion au serveur n\'a pas pu être établie. Veuillez vérifier que le nom d\'hôte, le nom d\'utilisateur, le mot de passe et le port sont corrects.';
$lang['Virtualmin.!error.account_limit_valid'] = 'Veuillez saisir une limite de compte valide.';
$lang['Virtualmin.!error.meta[plan].empty'] = 'Un plan VirtualMin est nécessaire.';
$lang['Virtualmin.!error.meta[template].empty'] = 'Un modèle VirtualMin est nécessaire.';
$lang['Virtualmin.!error.api.internal'] = 'Une erreur interne s\'est produite ou le serveur n\'a pas répondu à la demande.';
$lang['Virtualmin.!error.module_row.missing'] = 'Une erreur interne s\'est produite. La ligne du module n\'est pas disponible.';
$lang['Virtualmin.!error.virtualmin_domain.format'] = 'Veuillez saisir un nom de domaine valide, par exemple domain.com.';
$lang['Virtualmin.!error.virtualmin_domain.test'] = 'Le nom de domaine ne peut pas commencer par "test".';
$lang['Virtualmin.!error.virtualmin_username.format'] = 'Le nom d\'utilisateur ne peut contenir que des lettres et des chiffres et ne peut pas commencer par un chiffre.';
$lang['Virtualmin.!error.virtualmin_username.test'] = 'Le nom d\'utilisateur ne peut pas commencer par "test".';
$lang['Virtualmin.!error.virtualmin_username.length'] = 'Le nom d\'utilisateur doit comporter entre 1 et 16 caractères.';
$lang['Virtualmin.!error.virtualmin_password.valid'] = 'Le mot de passe doit comporter au moins 8 caractères.';
$lang['Virtualmin.!error.meta[domains_list].valid'] = 'Un ou plusieurs domaines du paquet ne sont pas valides.';
$lang['Virtualmin.package_fields.tooltip.domains_list'] = 'Entrez une liste CSV de domaines qui seront disponibles pour provisionner des sous-domaines, par exemple "domain1.com,domain2.com,domain3.com".';
$lang['Virtualmin.package_fields.domains_list'] = 'Liste des domaines disponibles';
$lang['Virtualmin.package_fields.sub_domains_disable'] = 'Désactiver';
$lang['Virtualmin.package_fields.sub_domains_enable'] = 'Activer';
$lang['Virtualmin.package_fields.sub_domains'] = 'Autoriser la vente de sous-domaines';
